@@ -1,3 +1,5 @@
+package glade;
+
 import java.io.IOException;
 
 import org.gnu.glade.LibGlade;
@@ -7,7 +9,7 @@ import org.gnu.gtk.event.LifeCycleEvent;
 
 public class Example1 {
 
-    private static final String gladeFilename = "example1.glade";
+    private static final String gladeFilename = "glade/example1.glade";
 
     private LibGlade libglade;
 
